==> Spire.Xls-13.9.0-py3-none-win_amd64.whl: spire/xls/CellValueChangedEventArgs.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class CellValueChangedEventArgs (SpireObject) :
    """

    """
    @property

    def OldValue(self)->'SpireObject':
        """
    <summary>
        Gets or sets the old value.
    </summary>
<value>The old value.</value>
        """
        GetDllLibXls().CellValueChangedEventArgs_get_OldValue.argtypes=[c_void_p]
        GetDllLibXls().CellValueChangedEventArgs_get_OldValue.restype=c_void_p
        intPtr = GetDllLibXls().CellValueChangedEventArgs_get_OldValue(self.Ptr)
        ret = None if intPtr==None else SpireObject(intPtr)
        return ret


    @OldValue.setter
    def OldValue(self, value:'SpireObject'):
        GetDllLibXls().CellValueChangedEventArgs_set_OldValue.argtypes=[c_void_p, c_void_p]
        GetDllLibXls().CellValueChangedEventArgs_set_OldValue(self.Ptr, value.Ptr)

    @property

    def NewValue(self)->'SpireObject':
        """
    <summary>
        Gets or sets the new value.
    </summary>
<value>The new value.</value>
        """
        GetDllLibXls().CellValueChangedEventArgs_get_NewValue.argtypes=[c_void_p]
        GetDllLibXls().CellValueChangedEventArgs_get_NewValue.restype=c_void_p
        intPtr = GetDllLibXls().CellValueChangedEventArgs_get_NewValue(self.Ptr)
        ret = None if intPtr==None else SpireObject(intPtr)
        return ret


    @NewValue.setter
    def NewValue(self, value:'SpireObject'):
        GetDllLibXls().CellValueChangedEventArgs_set_NewValue.argtypes=[c_void_p, c_void_p]
        GetDllLibXls().CellValueChangedEventArgs_set_NewValue(self.Ptr, value.Ptr)

    @property

    def Range(self)->'IXLSRange':
        """
    <summary>
        Gets or sets the range.
    </summary>
<value>The range.</value>
        """
        GetDllLibXls().CellValueChangedEventArgs_get_Range.argtypes=[c_void_p]
        GetDllLibXls().CellValueChangedEventArgs_get_Range.restype=c_void_p
        intPtr = GetDllLibXls().CellValueChangedEventArgs_get_Range(self.Ptr)
        ret = None if intPtr==None else XlsRange(intPtr)
        return ret


    @Range.setter
    def Range(self, value:'IXLSRange'):
        GetDllLibXls().CellValueChangedEventArgs_set_Range.argtypes=[c_void_p, c_void_p]
        GetDllLibXls().CellValueChangedEventArgs_set_Range(self.Ptr, value.Ptr)

==> Spire.Xls-14.4.4-py3-none-win_amd64.whl: spire/xls/CellValueChangedEventArgs.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class CellValueChangedEventArgs (SpireObject) :
    """

    """
    @property

    def OldValue(self)->'SpireObject':
        """
    <summary>
        Gets or sets the old value.
    </summary>
<value>The old value.</value>
        """
        GetDllLibXls().CellValueChangedEventArgs_get_OldValue.argtypes=[c_void_p]
        GetDllLibXls().CellValueChangedEventArgs_get_OldValue.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().CellValueChangedEventArgs_get_OldValue, self.Ptr)
        ret = None if intPtr==None else SpireObject(intPtr)
        return ret


    @OldValue.setter
    def OldValue(self, value:'SpireObject'):
        GetDllLibXls().CellValueChangedEventArgs_set_OldValue.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibXls().CellValueChangedEventArgs_set_OldValue, self.Ptr, value.Ptr)

    @property

    def NewValue(self)->'SpireObject':
        """
    <summary>
        Gets or sets the new value.
    </summary>
<value>The new value.</value>
        """
        GetDllLibXls().CellValueChangedEventArgs_get_NewValue.argtypes=[c_void_p]
        GetDllLibXls().CellValueChangedEventArgs_get_NewValue.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().CellValueChangedEventArgs_get_NewValue, self.Ptr)
        ret = None if intPtr==None else SpireObject(intPtr)
        return ret


    @NewValue.setter
    def NewValue(self, value:'SpireObject'):
        GetDllLibXls().CellValueChangedEventArgs_set_NewValue.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibXls().CellValueChangedEventArgs_set_NewValue, self.Ptr, value.Ptr)

    @property

    def Range(self)->'IXLSRange':
        """
    <summary>
        Gets or sets the range.
    </summary>
<value>The range.</value>
        """
        GetDllLibXls().CellValueChangedEventArgs_get_Range.argtypes=[c_void_p]
        GetDllLibXls().CellValueChangedEventArgs_get_Range.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().CellValueChangedEventArgs_get_Range, self.Ptr)
        ret = None if intPtr==None else XlsRange(intPtr)
        return ret


    @Range.setter
    def Range(self, value:'IXLSRange'):
        GetDllLibXls().CellValueChangedEventArgs_set_Range.argtypes=[c_void_p, c_void_p]
        CallCFunction(GetDllLibXls().CellValueChangedEventArgs_set_Range, self.Ptr, value.Ptr)
